@@ -5,8 +5,8 @@ from .views import *
 
 urlpatterns = [
     url(r'^admin/', include(admin.site.urls)),
-    url(r'^login/regular/$', django.contrib.auth.views.login, name='login_regular'),
-    url(r'^logout/regular/$', django.contrib.auth.views.logout, name='logout_regular'),
+    url(r'^login/$', django.contrib.auth.views.login, name='login'),
+    url(r'^logout/$', django.contrib.auth.views.logout, name='logout'),
     url(r'^$', page, name='homepage'),
     url(r'^page/([^/]+)/$', page, name='page'),
     url(r'^startclass/$', startclass, name='startclass'),
@@ -17,7 +17,10 @@ urlpatterns = [
     url(r'^([^/]+)/session/([0-9]+)/assignment/([0-9]+)/$', assignment, name='assignment'),
     url(r'^([^/]+)/session/([0-9]+)/students/$', progresses, name='progresses'),
     url(r'^([^/]+)/session/([0-9]+)/student/([^/]+)/$', progress, name='progress'),
-
-    url(r'^([^/]+)/session/([0-9]+)/add/$', add_assignment, name='add_assignment'),
-    url(r'^([^/]+)/session/([0-9]+)/assignment/([0-9]+)/add/$', add_step, name='add_step'),
+    url(r'^([^/]+)/session/([0-9]+)/student/$', add_student, name='add_student'),
+    url(r'^([^/]+)/session/([0-9]+)/student/([^/]+)/remove/$', remove_student, name='remove_student'),
+    url(r'^([^/]+)/session/([0-9]+)/add_assignment/$', add_assignment, name='add_assignment'),
+    url(r'^([^/]+)/session/([0-9]+)/assignment/([0-9]+)/duplicate/$', copy_assignment, name='copy_assignment'),
+#    url(r'^([^/]+)/quiz/$', quiz, name='quiz'),
+    url(r'^([^/]+)/session/([0-9]+)/assignment/([0-9]+)/add_step/$', add_step, name='add_step'),
 ]
